@@ -22,8 +22,8 @@ def parse_row_to_dict(row:dict) -> dict:
     row = row.copy()
     _json = lib.json_loads(row.pop("_json")) if "_json" in row else {}
     return {
-        **_json,
-        **row # columns takes precedence. So whatever is there to overwrite _json
+        **row, # ensure columns exists
+        **_json
     }
 
 def parse_smart_filtering(filters: dict, indexed_columns:list=[]) -> dict:
@@ -134,6 +134,11 @@ class Database(object):
         """
         return self.db.get_containers()
 
+    @staticmethod
+    def utcnow():
+        return lib.get_timestamp()
+
+
 class Item(dict):
     """
     Item/ActiveRecord
@@ -226,6 +231,7 @@ class Item(dict):
         self.container.delete(self._id)
         self._empty_self()
 
+    # ---
 
 
     def _req_int_prop(self, path:str) -> int:
@@ -256,7 +262,7 @@ class Item(dict):
             dec:1 - value to dec by
         Returns:    
             int - the value that was decremented
-        """        
+        """   
         self.set(path=path, value=self._req_int_prop(path) - dec)
         return self.get(path)
 
@@ -408,6 +414,7 @@ class Item(dict):
             if _ in self:
                 del self[_]
 
+
 class Container(object):
     """
     Container/Table
@@ -608,18 +615,22 @@ class Container(object):
 
         _id = lib.gen_id()
         ts = lib.get_timestamp()
-        xcolumns = self.DEFAULT_COLUMNS[:]
-        xparams = [_id, lib.json_dumps(doc), ts, ts]
+        doc.upate({
+            "_id": _id,
+            "_created_at": ts,
+            "_modified_at": ts,
+        })
+
+        xcolumns = ["_id", "_json", "_created_at", "_modified_at"]
+        xparams = [_id, lib.json_dumps(doc), lib.timestamp_to_str(ts), lib.timestamp_to_str(ts)]
         q = "INSERT INTO %s " % self.name
         
         # indexed data
-        # some data can't be overriden 
+        # some data can't be overwritten 
         for col in self.columns:
             if col in doc and col not in xcolumns:
-                _data = doc[col]
-                if _data:
-                    xcolumns.append(col)
-                    xparams.append(_data)
+                xcolumns.append(col)
+                xparams.append(doc[col])
 
         q += " ( %s ) VALUES ( %s ) " % (",".join(xcolumns), ",".join(["?" for _ in xparams]))
         
@@ -641,22 +652,22 @@ class Container(object):
         """
         rdoc = self.find_one(_id=_id, _as_document=False)
         if rdoc:
-            _doc = doc if replace else lib.dict_merge(lib.json_loads(rdoc["_json"]), doc)
             ts = lib.get_timestamp()
-            
+            _doc = doc if replace else lib.dict_merge(lib.json_loads(rdoc["_json"]), doc)
+            _doc["_modified_at"] = ts
+            _restricted_columns = self.DEFAULT_COLUMNS[:]
+
             xcolumns = ["_json", "_modified_at"]
-            xparams = [lib.json_dumps(_doc), ts]
+            xparams = [lib.json_dumps(_doc), lib.timestamp_to_str(ts)]
 
             q = "UPDATE %s SET " % self.name
             
             # indexed data
             # some data can't be overriden 
             for col in self.columns:
-                if col in _doc and col not in xcolumns:
-                    _data = _doc[col]
-                    if _data:
-                        xcolumns.append(col)
-                        xparams.append(_data)
+                if col in _doc and col not in _restricted_columns:
+                    xcolumns.append(col)
+                    xparams.append(_doc[col])
             q += ",".join(["%s = ?" % _ for _ in xcolumns])
             q += " WHERE _id=?"
             xparams.append(_id)
